# jrdf - Just rename the damn files

Utility that changes the Movies/Shows filenames in the Jellyfin structure

# Install

Suggested

```bash
pipx install jrdf
```
or

```bash
pip install -r requirements.txt
```

# Usage

```bash
jrdf -h
````

## Movies

```bash
jrdf -M folders
```

## TV Shows

```bash
jrdf -T folders
```

## Dry Run

```bash
jrdf -M/-T folders -d
```
